<?php
// $Id: og_global_limits.admin.inc,v 1.2 2009/05/21 00:49:05 elliottf Exp $

/**
 * This file handles the administrative
 *  functions for the og_global_limits module.
 *
 * @file: og_global_limits.admin.inc
 * @author: Elliott Foster
 * @copyright: NewMBC 2009
 */

/**
 * og_global_limits_settings - return the system settings
 *  form for the og_global_limits module.
 */
function og_global_limits_settings() {
  $form = array();

  $form['og_global_limits_max_per_group'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum number of members per group'),
    '#default_value' =>  variable_get('og_global_limits_max_per_group', 5),
    '#description' => t('Set the maximum number of users that may join a group.  Use 0 if you do not want to restrict group membership.'),
  );
  $form['og_global_limits_max_groups'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum number of groups'),
    '#default_value' => variable_get('og_global_limits_max_groups', 10),
    '#description' => t('Set the maximum nuber of groups at a user may create.  Use 0 if you do now want to restrict group creation.'),
  );

  return system_settings_form($form);
}

/**
 * og_global_limits_settings_validate - validate the system settings form
 */
function og_global_limits_settings_validate($form, &$form_state) {
  if (!is_numeric($form_state['values']['og_global_limits_max_per_group']) || $form_state['values']['og_global_limits_max_per_group'] < 0) {
    form_set_error('og_global_limits_max_per_group', t('You must enter a positive integer for the max per group limit.'));
  }

  if (!is_numeric($form_state['values']['og_global_limits_max_groups']) || $form_state['values']['og_global_limits_max_groups'] < 0) {
    form_set_error('og_global_limits_max_groups', t('You must enter a positive integer for the max groups limit.'));
  }

  // just in case we've got some bozo that wants float limits, round up
  // only do this if we didn't have any errors
  if (sizeof(form_get_errors()) == 0) {
    $form_state['values']['og_global_limits_max_per_group'] = ceil($form_state['values']['og_global_limits_max_per_group']);
    $form_state['values']['og_global_limits_max_groups'] = ceil($form_state['values']['og_global_limits_max_groups']);
  }
}

